@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 #include "indexedstrategy.h"
 #include "utils/searchutility.h"
+#include "utils/lucenequeryutils.h"
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -25,41 +26,6 @@ QueryBuilder::QueryBuilder()
 {
 }
 
-Lucene::String QueryBuilder::processString(const QString &str, bool caseSensitive) const
-{
-    // Step 1: 转成 std::wstring
-    std::wstring input = str.toStdWString();
-
-    // Step 2: 需要转义的 Lucene 特殊字符（按 Lucene 语法）
-    static const std::wstring specialChars = L"+-&&||!(){}[]^\"~*?:\\/";
-
-    std::wstring escaped;
-    escaped.reserve(input.size() * 2);   // 预留空间，提高性能
-
-    for (wchar_t ch : input) {
-        // 如果是 Lucene 特殊字符，就在前面加 '\'
-        if (specialChars.find(ch) != std::wstring::npos) {
-            escaped += L'\\';
-        }
-        escaped += ch;
-    }
-
-    // Step 3: 转成 Lucene::String（Lucene++ 使用的是 UTF-8）
-    QString tempQString = QString::fromStdWString(escaped);
-    QByteArray utf8Bytes = tempQString.toUtf8();
-    Lucene::String luceneStr = Lucene::StringUtils::toUnicode(std::string(utf8Bytes.constData(), utf8Bytes.length()));
-    if (luceneStr.empty()) {
-        luceneStr = Lucene::StringUtils::toUnicode(str.toStdString());
-    }
-
-    // Step 4: 如果不区分大小写就转小写（Lucene::String 是 Unicode）
-    if (!caseSensitive) {
-        Lucene::StringUtils::toLower(luceneStr);
-    }
-
-    return luceneStr;
-}
-
 Lucene::QueryPtr QueryBuilder::buildTypeQuery(const QStringList &types) const
 {
     if (types.isEmpty()) {
@@ -138,7 +104,7 @@ Lucene::QueryPtr QueryBuilder::buildCommonQuery(const QString &keyword, bool cas
         parser->setAllowLeadingWildcard(true);
     }
 
-    return parser->parse(processString(keyword, caseSensitive));
+    return parser->parse(LuceneQueryUtils::processQueryString(keyword, caseSensitive));
 }
 
 Lucene::QueryPtr QueryBuilder::buildSimpleQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const
@@ -148,7 +114,17 @@ Lucene::QueryPtr QueryBuilder::buildSimpleQuery(const QString &keyword, bool cas
 
 Lucene::QueryPtr QueryBuilder::buildWildcardQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const
 {
-    return buildCommonQuery(keyword, caseSensitive, analyzer, true);
+    if (keyword.isEmpty()) {
+        return nullptr;
+    }
+    
+    // 对于通配符查询，使用file_name_lower字段（非分词）而非file_name（分词）
+    QString processedKeyword = caseSensitive ? keyword : keyword.toLower();
+    
+    // 直接构建WildcardQuery，不使用QueryParser避免分词干扰
+    return newLucene<WildcardQuery>(
+        newLucene<Term>(L"file_name_lower", 
+                       StringUtils::toUnicode(processedKeyword.toStdString())));
 }
 
 Lucene::QueryPtr QueryBuilder::buildBooleanQuery(const QStringList &terms, bool caseSensitive, SearchQuery::BooleanOperator op, const Lucene::AnalyzerPtr &analyzer) const
@@ -335,8 +311,8 @@ FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType
         return SearchType::FileExt;
     }
 
-    // 有通配符的搜索
-    if (hasKeyword && (keyword.contains('*') || keyword.contains('?'))) {
+    // 通配符查询类型（显式指定）
+    if (query.type() == SearchQuery::Type::Wildcard) {
         return SearchType::Wildcard;
     }
 
@@ -433,7 +409,7 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
     // 构建查询
     QueryPtr luceneQuery;
     try {
-        luceneQuery = buildLuceneQuery(query);
+        luceneQuery = buildLuceneQuery(query, searchPath);
         if (!luceneQuery) {
             emit errorOccurred(SearchError(SearchErrorCode::InvalidQuery));
             return;
@@ -465,6 +441,7 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
     resultTimer.start();
     auto docsSize = searchResults->scoreDocs.size();
     m_results.reserve(docsSize);
+
     // 实时处理搜索结果
     for (int i = 0; i < docsSize; i++) {
         if (m_cancelled.load()) {
@@ -492,7 +469,7 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
             }
 
             // 处理搜索结果
-            if (Q_UNLIKELY(m_options.resultFoundEnabled())) {
+            if (Q_UNLIKELY(m_options.detailedResultsEnabled())) {
                 QString type = QString::fromStdWString(doc->get(L"file_type"));
                 QString time = QString::fromStdWString(doc->get(L"modify_time_str"));
                 QString size = QString::fromStdWString(doc->get(L"file_size_str"));
@@ -503,6 +480,10 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
                 m_results.append(result);
             }
 
+            // 实时发送结果
+            if (Q_UNLIKELY(m_options.resultFoundEnabled()))
+                emit resultFound(m_results.last());
+
         } catch (const LuceneException &e) {
             qWarning() << "Error processing result:" << QString::fromStdWString(e.getError());
             continue;
@@ -523,12 +504,10 @@ SearchResult FileNameIndexedStrategy::processSearchResult(const QString &path, c
     api.setIsDirectory(type == "dir");
     api.setFileType(type);
 
-    // perf: resultFound too slow!
-    emit resultFound(result);
     return result;
 }
 
-Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &query) const
+Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &query, const QString &searchPath) const
 {
     BooleanQueryPtr finalQuery = newLucene<BooleanQuery>();
     bool hasValidQuery = false;
@@ -634,6 +613,15 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
         break;
     }
 
+    // Add path prefix query optimization
+    if (hasValidQuery && SearchUtility::shouldUsePathPrefixQuery(searchPath)) {
+        QueryPtr pathPrefixQuery = LuceneQueryUtils::buildPathPrefixQuery(searchPath, "full_path");
+        if (pathPrefixQuery) {
+            finalQuery->add(pathPrefixQuery, BooleanClause::MUST);
+            qInfo() << "Using path prefix query for optimization:" << searchPath;
+        }
+    }
+
     return hasValidQuery ? finalQuery : nullptr;
 }
 
