@@ -516,7 +516,40 @@ bool isPathInFileNameIndexDirectory(const QString &path)
 
 bool isFileNameIndexDirectoryAvailable()
 {
-    return IndexReader::indexExists(FSDirectory::open(fileNameIndexDirectory().toStdWString()));
+    try {
+        const QString &indexDir = fileNameIndexDirectory();
+        bool exists = IndexReader::indexExists(FSDirectory::open(indexDir.toStdWString()));
+        return exists;
+    } catch (const LuceneException &e) {
+        qWarning() << "Failed to check index existence:" << QString::fromStdWString(e.getError());
+        return false;
+    }
+}
+
+bool isFileNameIndexReadyForSearch()
+{
+    // First check if the index physically exists
+    if (!isFileNameIndexDirectoryAvailable()) {
+        qDebug() << "Index directory does not exist physically.";
+        return false;
+    }
+
+    // Then check the status to ensure it's in monitoring state
+    std::optional<QString> currentStatus = fileNameIndexStatus();
+    if (!currentStatus) {
+        qWarning() << "Failed to get file name index status.";
+        return false;
+    }
+
+    const QStringList &validStatus = { "scanning", "monitoring" };
+    const QString &status = currentStatus.value();
+    if (!validStatus.contains(status)) {
+        qDebug() << "Index status is '" << status
+                 << "', expected 'scanning' or 'monitoring'. Index not ready for search.";
+        return false;
+    }
+
+    return true;
 }
 
 std::optional<QString> fileNameIndexStatus()
@@ -605,5 +638,27 @@ QStringList deepinAnythingFileTypes()
     return kTypes;
 }
 
+bool shouldUsePathPrefixQuery(const QString &searchPath)
+{
+    // Don't use path prefix query for root directory
+    if (searchPath == "/" || searchPath.isEmpty()) {
+        return false;
+    }
+
+    // Check if it's one of the default indexed directories
+    const QStringList &defaultDirs = Global::defaultIndexedDirectory();
+    for (const QString &defaultDir : defaultDirs) {
+        QString normalizedDefault = QDir::cleanPath(defaultDir);
+        QString normalizedSearch = QDir::cleanPath(searchPath);
+
+        // Don't use path prefix query if search path is one of the default indexed directories
+        if (normalizedSearch == normalizedDefault) {
+            return false;
+        }
+    }
+
+    return true;
+}
+
 }   // namespace SearchUtility
 DFM_SEARCH_END_NS
